@@ -13,9 +13,39 @@
  Original:	March 1990
 
  $Log:	DevServerP.h,v $
- * Revision 8.30  2001/11/12  10:00:00  10:00:00  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ * Revision 8.40  2002/03/18  10:11:00  10:11:00  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:53  05:48:53  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:21  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:46  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:44  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:08  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:49  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:45:08  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:07  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 10:00:00  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:10  goetz
  fixed error in CORBA::is_nil() test
 
@@ -252,7 +282,7 @@
  */
 #ifdef _IDENT
 static char DevServerPh[] =
-"@(#)$Header: DevServerP.h,v 8.30 2001/11/12 10:00:00 goetz Rel $";
+"@(#)$Header: DevServerP.h,v 8.40 2002/03/18 10:11:00 goetz Rel $";
 #endif /* _IDENT */
 
 /*
