@@ -1,4 +1,7 @@
-/* $Log: dbm_xdr.cpp,v $
+/* $Log:	dbm_xdr.cpp,v $
+Revision 6.10  2001/01/08  11:45:53  11:45:53  goetz (Andy Goetz)
+added patch by B.Pedersen to support querying events
+
  * Revision 6.9  2000/03/15 17:07:56  taurel
  * Change compilation variable from -solaris to sun
  *
@@ -434,6 +437,27 @@ xdr_cmd_que(xdrs,objp)
 	return (TRUE);
 }
 
+/* event query */
+bool_t _WINAPI
+#if defined __STDC__ | defined __STDCPP__
+ xdr_event_que(XDR *xdrs,event_que *objp)
+#else
+xdr_event_que(xdrs,objp)
+	XDR *xdrs;
+	event_que *objp;
+#endif	/* __STDC__ */
+{
+	if (!xdr_int(xdrs, &objp->db_err))
+	{
+		return (FALSE);
+	}
+	if (!xdr_u_int(xdrs, &objp->xevent_code))
+	{
+		return (FALSE);
+	}
+	return (TRUE);
+}
+
 
 
 /* For db_psdev_register function */
