@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v 6.14 2001/09/12 14:53:02 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v 6.16 2002/04/09 13:47:24 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -16,6 +16,12 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v
 
 
  * $Log: reconnect_cli.c,v $
+ * Revision 6.16  2002/04/09 13:47:24  goetz
+ * ported to Windows
+ *
+ * Revision 6.15  2002/03/07 15:47:51  goetz
+ * added no database to db_getdevlist(), error DbErr_NoDatabase to others
+ *
  * Revision 6.14  2001/09/12 14:53:02  taurel
  * Add db_exp.cpp file with function to get Tango device name in db_getdevexp call (C++ only)
  *
@@ -60,17 +66,13 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/reconnect_cli.c,v
 #include <macros.h>
 #include <db_setup.h>
 #include <db_xdr.h>
-
-#if defined(_NT)
-#include <API.h>
-#include <DevErrors.h>
-#include <nm_rpc.h>
-
-#else
 #include <API.h>
 #include <private/ApiP.h>
 #include <DevErrors.h>
 
+#if defined(_NT)
+#include <rpc.h>
+#else
 #ifdef _OSK
 #include <inet/socket.h>
 #include <inet/netdb.h>
