@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.14 2001/09/12 14:53:02 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.16 2002/04/09 13:47:24 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -18,6 +18,12 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.
  Original   :   January 1991
 
  * $Log: setacc_clnt.c,v $
+ * Revision 6.16  2002/04/09 13:47:24  goetz
+ * ported to Windows
+ *
+ * Revision 6.15  2002/03/07 15:47:51  goetz
+ * added no database to db_getdevlist(), error DbErr_NoDatabase to others
+ *
  * Revision 6.14  2001/09/12 14:53:02  taurel
  * Add db_exp.cpp file with function to get Tango device name in db_getdevexp call (C++ only)
  *
@@ -116,7 +122,7 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.
 #include <db_xdr.h>
 
 #if defined(_NT)
-#include <nm_rpc.h>
+#include <rpc.h>
 #else
 #include <rpc/rpc.h>
 #endif
