@@ -13,15 +13,45 @@
  Original:	June 1992
 
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:59 $
+ $Revision: 8.40 $
+ $Date: 2002/03/18 10:10:48 $
 
  $Author: goetz $
 
  $Log:	ApiP.h,v $
- * Revision 8.30  2001/11/12  09:59:59  09:59:59  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ * Revision 8.40  2002/03/18  10:10:48  10:10:48  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:51  05:48:51  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:20  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:45  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:43  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:48  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:56  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:06  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:59  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:08  goetz
  fixed error in CORBA::is_nil() test
 
@@ -214,7 +244,7 @@
  */
 #ifdef _IDENT
 static char ApiPh[] =
-"@(#)$Header: ApiP.h,v 8.30 2001/11/12 09:59:59 goetz Rel $";
+"@(#)$Header: ApiP.h,v 8.40 2002/03/18 10:10:48 goetz Rel $";
 #endif /* _IDENT */
 
 
@@ -351,6 +381,9 @@ typedef struct {
 		long		vers_number;
 		DevBoolean	device_server;
 		DevBoolean	asynch_rpc;
+		DevBoolean	no_database;
+		int		device_no;
+		char		**device_list;
 	       } configuration_flags; 
 	      
 /*
@@ -613,6 +646,7 @@ void event_client_cleanup
 
 long tango_db_import(char*, char*, long, long*);
 long tango_dev_import(char*, long, devserver*, long*);
+long tango_dev_free(devserver,long*); 
 long tango_dev_putget(devserver,long,void*,long,void*,long,long*);
 long tango_dev_putget_raw(devserver,long,void*,long,void*,long,long*);
 long tango_dev_cmd_query(devserver,DevVarCmdArray*,long*); 
@@ -622,9 +656,10 @@ long tango_dev_ping(devserver,long*);
 
 long dev_notimported_init(char*, long, long, devserver*, long*);
 
-/* dynamic error string  */
+/* dynamic error string handling */
 
 long dev_error_push PT_( (char *error_string) );
+long dev_error_clear PT_( () );
 
 #ifdef __cplusplus
 }
