@@ -1,5 +1,5 @@
 static char RcsId[]         = 
-"@(#)$Header: ds_prog_vers3.c,v 8.20 2001/01/08 13:14:50 goetz Rel $";
+"@(#)$Header: ds_prog_vers3.c,v 8.40 2002/03/18 10:10:54 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -15,14 +15,74 @@ static char RcsId[]         =
  Original   :	November 1994
 
 
- $Revision: 8.20 $
- $Date: 2001/01/08 13:14:50 $
+ $Revision: 8.40 $
+ $Date: 2002/03/18 10:10:54 $
  $Author: goetz $
 
  $Log:	ds_prog_vers3.c,v $
- * Revision 8.20  2001/01/08  13:14:50  13:14:50  goetz (Andy Goetz)
- * added patch by B.Pedersen to support querying events
+ * Revision 8.40  2002/03/18  10:10:54  10:10:54  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:51  05:48:51  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:25  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:20  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:45  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:43  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:08  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:48  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:45:02  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:06  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:59  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
+ Revision 8.29  2001/07/26 05:05:09  goetz
+ fixed error in CORBA::is_nil() test
+
+ Revision 8.28  2001/07/25 13:13:15  goetz
+ tango cmd_query in_name and out_name left NULL; desc replaces reason for errors
+
+ Revision 8.27  2001/07/25 13:05:39  goetz
+ added space to dev_error_str() string; test CORBA::is_nil() for tango database
+
+ Revision 8.26  2001/04/10 14:24:34  goetz
+ set timeout on tango devices to 3 seconds
+
+ Revision 8.25  2001/03/20 11:56:39  goetz
+ DevCmdNameList searched before database for commands in tango_api.cpp
+
+ Revision 8.24  2001/03/10 16:38:20  goetz
+ ported tango_api to TANGO 2
+
+ Revision 8.23  2001/02/28 12:26:48  goetz
+ converted TANGO states to TACO states
+
+ Revision 8.22  2001/01/16 10:09:45  goetz
+ applied J.Quick's patch for security; removed stderr from DevServerMain.c
+
+ * Revision 8.21  2001/01/15  11:36:40  11:36:40  goetz (Andy Goetz)
+ * added check for ds == NULL in all dev_ api routines; changed ds__signal prototype
+ * 
+ Revision 8.20  2001/01/08 13:14:50  goetz
+ added patch by B.Pedersen to support querying events
+
  Revision 8.19  2000/12/11 12:06:44  goetz
  fixed bugs with TANGO interface returning unsigned values and states
 
