@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: event_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
+static char RcsId[] = "@(#)$Header: event_api.c,v 8.40 2002/03/18 10:10:44 goetz Rel $";
 /*+*******************************************************************
 
  File       :	event_api.c
@@ -33,15 +33,45 @@ static char RcsId[] = "@(#)$Header: event_api.c,v 8.30 2001/11/12 09:59:58 goetz
 
  Original   :	April 1999
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:58 $
+ $Revision: 8.40 $
+ $Date: 2002/03/18 10:10:44 $
 
  $Author: goetz $
 
  $Log:	event_api.c,v $
- * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ * Revision 8.40  2002/03/18  10:10:44  10:10:44  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:50  05:48:50  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:24  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:18  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:44  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:42  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:47  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:52  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:05  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:58  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:07  goetz
  fixed error in CORBA::is_nil() test
 
@@ -326,8 +356,11 @@ long _DLLFunc dev_event_listen (devserver ds, long event_type,
  * save the device's nethost in an intermediate variable
  * to make it more accessible
  */
-	i_nethost = ds->i_nethost;
-	nethost = &multi_nethost[i_nethost];
+	if (!ds->no_database)
+	{
+		i_nethost = ds->i_nethost;
+		nethost = &multi_nethost[i_nethost];
+	}
 
 
 /*
@@ -360,11 +393,14 @@ long _DLLFunc dev_event_listen (devserver ds, long event_type,
  * verify the security key
  */
 
-	if ( nethost->config_flags.security == True )
+	if (!ds->no_database)
 	{
-		if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+		if ( nethost->config_flags.security == True )
 		{
-			return (DS_NOTOK);
+			if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+			{
+				return (DS_NOTOK);
+			}
 		}
 	}
 
@@ -776,8 +812,11 @@ long _DLLFunc dev_event_unlisten (devserver ds, long event_type,
  * save the device's nethost in an intermediate variable
  * to make it more accessible
  */
-	i_nethost = ds->i_nethost;
-	nethost = &multi_nethost[i_nethost];
+	if (!ds->no_database)
+	{
+		i_nethost = ds->i_nethost;
+		nethost = &multi_nethost[i_nethost];
+	}
 
 
 /*
@@ -810,11 +849,14 @@ long _DLLFunc dev_event_unlisten (devserver ds, long event_type,
  * verify the security key
  */
 
-	if ( nethost->config_flags.security == True )
+	if (!ds->no_database)
 	{
-		if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+		if ( nethost->config_flags.security == True )
 		{
-			return (DS_NOTOK);
+			if ( verify_sec_key (ds, &client_id, error) == DS_NOTOK )
+			{
+				return (DS_NOTOK);
+			}
 		}
 	}
 
@@ -1211,6 +1253,8 @@ long _DLLFunc dev_event_query (devserver ds, DevVarEventArray *vareventarr, long
 	u_int 		res_tab_size = sizeof(res_tab) / 
 	    sizeof(db_resource);
 	long		status;
+	static char	**event_names=NULL;
+	int		n_event_names;
 
 	*error = 0;
 #ifdef EBUG
@@ -1286,6 +1330,17 @@ long _DLLFunc dev_event_query (devserver ds, DevVarEventArray *vareventarr, long
          * structure, coming from the server.
          */
 
+        if (dev_query_out.var_argument.length > 0)
+        {
+                event_names = (char**)realloc(event_names,dev_query_out.var_argument.length*sizeof(char*));
+                for (i=0; i<dev_query_out.var_argument.length; i++)
+                {
+                        event_names[i] = (char*)malloc(strlen(*(char**)dev_query_out.var_argument.sequence[i].argument)+1);
+                        sprintf(event_names[i],"%s",*(char**)dev_query_out.var_argument.sequence[i].argument);
+                }
+        }
+	n_event_names = dev_query_out.var_argument.length;
+
 	xdr_free ((xdrproc_t)xdr_DevVarArgumentArray,
 	    (char *)&(dev_query_out.var_argument));
 
@@ -1326,19 +1381,37 @@ long _DLLFunc dev_event_query (devserver ds, DevVarEventArray *vareventarr, long
 		vareventarr->sequence[i].event      = dev_query_out.sequence[i].event;
 		vareventarr->sequence[i].out_type = dev_query_out.sequence[i].out_type;
 
-		/*
+/*
+ * check to see if device server returned event names
+ */
+                if (i < n_event_names && n_event_names > 0)
+                {
+                        sprintf(vareventarr->sequence[i].event_name,"%s",event_names[i]);
+                        free(event_names[i]);
+                }
+                else
+                {
+	   /*
 	    * get command name string from the resource database
 	    */
+			if (!ds->no_database)
+			{
 
-		if ( (ret_stat = get_event_string (ds, vareventarr->sequence[i].event, 
-		    vareventarr->sequence[i].event_name, 
-		    error )) == DS_NOTOK )
-		{
+				if ( (ret_stat = get_event_string (ds, vareventarr->sequence[i].event, 
+		    		vareventarr->sequence[i].event_name, 
+		    		error )) == DS_NOTOK )
+				{
 			/*
 	       * An error will be only returned if the database
 	       * access fails.
 	       */
-			return (DS_NOTOK);
+					return (DS_NOTOK);
+				}
+			}
+			else
+			{
+				sprintf(vareventarr->sequence[i].event_name,"event%s",i);
+			}
 		}
 
 
@@ -1348,27 +1421,29 @@ long _DLLFunc dev_event_query (devserver ds, DevVarEventArray *vareventarr, long
 	    *  DS_WARNING.
 	    */
 
-		if ( ret_stat != DS_WARNING )
+		if (!ds->no_database)
 		{
+			if ( ret_stat != DS_WARNING )
+			{
 			/*
 	       * Limit the class_name and the command_name
 	       * strings to 19 characters. This is the limit
 	       * of the static database name fields.
 	       */
 
-			length = strlen (dev_query_out.class_name);
-			if ( length > MAX_RESOURCE_FIELD_LENGTH )
-				length = MAX_RESOURCE_FIELD_LENGTH;
-			strncpy (class_name, dev_query_out.class_name, 
-			    MAX_RESOURCE_FIELD_LENGTH);
-			class_name[(_Int)length] = '\0';
+				length = strlen (dev_query_out.class_name);
+				if ( length > MAX_RESOURCE_FIELD_LENGTH )
+					length = MAX_RESOURCE_FIELD_LENGTH;
+				strncpy (class_name, dev_query_out.class_name, 
+			    	MAX_RESOURCE_FIELD_LENGTH);
+				class_name[(_Int)length] = '\0';
 
-			length = strlen (vareventarr->sequence[i].event_name);
-			if ( length > MAX_RESOURCE_FIELD_LENGTH )
-				length = MAX_RESOURCE_FIELD_LENGTH;
-			strncpy (event_name, vareventarr->sequence[i].event_name,
-			    MAX_RESOURCE_FIELD_LENGTH);
-			event_name[(_Int)length] = '\0';
+				length = strlen (vareventarr->sequence[i].event_name);
+				if ( length > MAX_RESOURCE_FIELD_LENGTH )
+					length = MAX_RESOURCE_FIELD_LENGTH;
+				strncpy (event_name, vareventarr->sequence[i].event_name,
+			    	MAX_RESOURCE_FIELD_LENGTH);
+				event_name[(_Int)length] = '\0';
 
 /*
  *  setup resource path to read information about
@@ -1378,32 +1453,40 @@ long _DLLFunc dev_event_query (devserver ds, DevVarEventArray *vareventarr, long
  * nethost domain i.e. i_nethost != 0
  */
 
-			if (ds->i_nethost > -1)
-			{
-				sprintf(res_path, "//%s/CLASS/%s/%s",
-				   get_nethost_by_index(ds->i_nethost, error),
-				   class_name, event_name);
-			}
+				if (ds->i_nethost > -1)
+				{
+					sprintf(res_path, "//%s/CLASS/%s/%s",
+				   	get_nethost_by_index(ds->i_nethost, error),
+				   	class_name, event_name);
+				}
 /*
  * use default nethost
  */
-			else
-			{
-				sprintf (res_path, "CLASS/%s/%s", 
-				   class_name, event_name);
-			}
+				else
+				{
+					sprintf (res_path, "CLASS/%s/%s", 
+				   	class_name, event_name);
+				}
 
 			/*
 	       *  read CLASS resources from database
 	       */
 
-			res_tab[0].resource_adr = &(vareventarr->sequence[i].out_name);
+				res_tab[0].resource_adr = &(vareventarr->sequence[i].out_name);
 
-			if (db_getresource (res_path, res_tab, res_tab_size, error) < 0)
-			{
-				return (-1);
+				if (db_getresource (res_path, res_tab, res_tab_size, error) < 0)
+				{
+					return (-1);
+				}
 			}
 		}
+/*
+ * no database, set out_name to NULL
+ */
+		else
+		{
+			vareventarr->sequence[i].out_name = NULL;
+		}
 	}
 
 	/*
