@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.30 2001/11/12 09:59:58 goetz Rel $";
+static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.40 2002/03/18 10:10:45 goetz Rel $";
 /*+*******************************************************************
 
  File       :	tango_api.c
@@ -17,15 +17,45 @@ static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.30 2001/11/12 09:59:58 goe
 
  Original   :	December 1999
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:58 $
+ $Revision: 8.40 $
+ $Date: 2002/03/18 10:10:45 $
 
  $Author: goetz $
 
  $Log:	tango_api.cpp,v $
-// Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
-// updated C port for Windows 95/98/NT using Visual C++ 6
+// Revision 8.40  2002/03/18  10:10:45  10:10:45  goetz (Andy Goetz)
+// removed ^M from files which were confusing Ultra C++ compiler
 // 
+// Revision 8.39  2002/03/18  05:48:50  05:48:50  goetz (Andy Goetz)
+// added tango_dev_free() and dev_error_clear(); error message in command_handler
+// 
+ Revision 8.38  2002/03/13 07:29:24  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:18  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:44  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:42  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:47  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:53  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:05  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:58  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:07  goetz
  fixed error in CORBA::is_nil() test
 
@@ -143,6 +173,7 @@ static char *tango_host_c_str=NULL;
 #define TANGO_DEV_NOT_IMPORTED 	0
 #define TANGO_DEV_IMPORTED 	1
 #define TANGO_BAD_CONNECTION	2
+#define TANGO_DEV_FREE		3
 
 extern long debug_flag;
 extern char *dev_error_string;
@@ -227,6 +258,7 @@ long tango_db_import(char *db_name, char *db_host, long db_port, long *error)
 long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *error)
 {
 	_tango_device tango_device_tmp;
+	long tango_device_free;
 
 	if (!tango_dbase_init) 
 	{
@@ -358,7 +390,24 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
                 	*error = DevErr_InsufficientMemory;
                 	return(DS_NOTOK);
         	}
-		tango_device.push_back(tango_device_tmp);
+		tango_device_free = -1;
+		for (long i = 0; i < tango_device.size(); i++)
+		{
+			if (tango_device[i].flag == TANGO_DEV_FREE)
+			{
+				tango_device_free = i;
+			}
+		}
+		if (tango_device_free < 0)
+		{
+			tango_device.push_back(tango_device_tmp);
+			n_tango_device = tango_device.size()-1;
+		}
+		else
+		{
+			tango_device[tango_device_free] = tango_device_tmp;
+			n_tango_device = tango_device_free;
+		}
         	sprintf((*ds_ptr)->device_name,"%s",dev_name);
         	sprintf((*ds_ptr)->device_class,"%s",(char*)dev_info->dev_class);
         	sprintf((*ds_ptr)->device_type,"TANGO_Device");
@@ -393,6 +442,32 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 	return(0);
 }
 
+/*+**********************************************************************
+ Function   :   extern long tango_dev_free()
+
+ Description:   free a TANGO device
+
+ Arg(s) In  :   devserver ds  - device server structure
+
+ Arg(s) Out :   none
+
+ Return(s)  :   DS_OK or DS_NOTOK
+***********************************************************************-*/
+
+long tango_dev_free(devserver ds, long *error)
+{
+	_tango_device tango_device_tmp;
+
+	//delete tango_device[ds->ds_id].cmd_name;
+	//delete tango_device[ds->ds_id].cmd_value;
+	//delete tango_device[ds->ds_id].argin_type;
+	//delete tango_device[ds->ds_id].argout_type;
+	tango_device[ds->ds_id].flag = TANGO_DEV_FREE;
+	free(ds);
+
+	return(0);
+}
+
 /*+**********************************************************************
  Function   :   extern long tango_dev_reimport()
 
