@@ -1,5 +1,5 @@
 static char RcsId[] = 
-"@(#)$Header: util_api.c,v 8.30 2001/11/12 09:59:58 goetz Rel $";
+"@(#)$Header: util_api.c,v 8.40 2002/03/18 10:10:40 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -16,15 +16,45 @@ static char RcsId[] =
 
  Original   :	April 1993
 
- $Revision: 8.30 $
- $Date: 2001/11/12 09:59:58 $
+ $Revision: 8.40 $
+ $Date: 2002/03/18 10:10:40 $
 
  $Author: goetz $
 
  $Log:	util_api.c,v $
- * Revision 8.30  2001/11/12  09:59:58  09:59:58  goetz (Andy Goetz)
- * updated C port for Windows 95/98/NT using Visual C++ 6
+ * Revision 8.40  2002/03/18  10:10:40  10:10:40  goetz (Andy Goetz)
+ * removed ^M from files which were confusing Ultra C++ compiler
  * 
+ * Revision 8.39  2002/03/18  05:48:50  05:48:50  goetz (Andy Goetz)
+ * added tango_dev_free() and dev_error_clear(); error message in command_handler
+ * 
+ Revision 8.38  2002/03/13 07:29:24  goetz
+ fixed bug initializing struct _devserver to zero; rpc_protocol=D_UDP
+
+ Revision 8.37  2002/03/11 14:20:18  goetz
+ initalise prog_number and config_flags to zero at startup
+
+ Revision 8.36  2002/03/07 15:58:44  goetz
+ fixed leak in extract_device_name
+
+ Revision 8.35  2002/03/06 22:08:42  goetz
+ made stateless import and reimport work for no database devices
+
+ Revision 8.34  2002/03/06 21:00:07  goetz
+ added -nodb option to device_server(); suppressed -m -s; improved dev_cmd_query
+
+ Revision 8.33  2002/03/05 11:52:47  goetz
+ added command name to C++ commands_list, asynchronous and events support -nodb
+
+ Revision 8.32  2002/03/03 22:44:48  goetz
+ added TACO-lite option i.e. no database
+
+ Revision 8.31  2002/02/28 12:13:05  goetz
+ setup_config() and setup_config_multi() now call rpc_nt_init() for Windows
+
+ Revision 8.30  2001/11/12 09:59:58  goetz
+ updated C port for Windows 95/98/NT using Visual C++ 6
+
  Revision 8.29  2001/07/26 05:05:07  goetz
  fixed error in CORBA::is_nil() test
 
@@ -681,9 +711,10 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
 	long		ret_stat;
 	char		res_path [LONG_NAME_SIZE];
 	int		i;
-	u_int 		res_tab_size = sizeof(res_tab) / 
-	    sizeof(db_resource);
+	u_int 		res_tab_size = sizeof(res_tab) / sizeof(db_resource);
 	long		status;
+	static char	**cmd_names=NULL;
+	int		n_cmd_names;
 
 	*error = 0;
 #ifdef EBUG
@@ -764,6 +795,17 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
          * structure, coming from the server.
          */
 
+	if (dev_query_out.var_argument.length > 0)
+	{
+		cmd_names = (char**)realloc(cmd_names,dev_query_out.var_argument.length*sizeof(char*));
+		for (i=0; i<dev_query_out.var_argument.length; i++)
+		{
+			cmd_names[i] = (char*)malloc(strlen(*(char**)dev_query_out.var_argument.sequence[i].argument)+1);
+			sprintf(cmd_names[i],"%s",*(char**)dev_query_out.var_argument.sequence[i].argument);
+		}
+	}
+	n_cmd_names = dev_query_out.var_argument.length;
+			
 	xdr_free ((xdrproc_t)xdr_DevVarArgumentArray,
 	    (char *)&(dev_query_out.var_argument));
 
@@ -795,59 +837,81 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
 
 	for ( i=0; (u_long)i<varcmdarr->length; i++ )
 	{
-		/*
-	    * initialise varcmdarr->sequence[i] with command and
-	    * argument types, returned with dev_query_out from the
-	    * device servers command list.
-	    */
+/*
+ * initialise varcmdarr->sequence[i] with command and
+ * argument types, returned with dev_query_out from the
+ * device servers command list.
+ */
 
 		varcmdarr->sequence[i].cmd      = dev_query_out.sequence[i].cmd;
 		varcmdarr->sequence[i].in_type  = dev_query_out.sequence[i].in_type;
 		varcmdarr->sequence[i].out_type = dev_query_out.sequence[i].out_type;
 
-		/*
-	    * get command name string from the resource database
-	    */
+/*
+ * get command name string from the resource database
+ */
 
-		if ( (ret_stat = get_cmd_string (ds, varcmdarr->sequence[i].cmd, 
-		    varcmdarr->sequence[i].cmd_name, 
-		    error )) == DS_NOTOK )
+
+/* 
+ * check to see if device server returned command names 
+ */
+		if (i < n_cmd_names && n_cmd_names > 0)
 		{
-			/*
-	       * An error will be only returned if the database
-	       * access fails.
-	       */
-			return (DS_NOTOK);
+			sprintf(varcmdarr->sequence[i].cmd_name,"%s",cmd_names[i]);
+			free(cmd_names[i]);
 		}
-
-
-		/*
-	    *  Check wether command name was found.
-	    *  If the name was not found, get_cmd_string() returns
-	    *  DS_WARNING.
-	    */
-
-		if ( ret_stat != DS_WARNING )
+		else
+		{
+			if (!ds->no_database)
+			{
+				if ( (ret_stat = get_cmd_string (ds, varcmdarr->sequence[i].cmd, 
+		    		varcmdarr->sequence[i].cmd_name, 
+		    		error )) == DS_NOTOK )
+				{
+/*
+ * An error will be only returned if the database
+ * access fails.
+ */
+					return (DS_NOTOK);
+				}
+			}
+			else
+			{
+				sprintf(varcmdarr->sequence[i].cmd_name,"command%d",i);
+			}
+		}
+		if (!ds->no_database)
 		{
-			/*
-	       * Limit the class_name and the command_name
-	       * strings to 19 characters. This is the limit
-	       * of the static database name fields.
-	       */
 
-			length = strlen (dev_query_out.class_name);
-			if ( length > MAX_RESOURCE_FIELD_LENGTH )
-				length = MAX_RESOURCE_FIELD_LENGTH;
-			strncpy (class_name, dev_query_out.class_name, 
-			    MAX_RESOURCE_FIELD_LENGTH);
-			class_name[(_Int)length] = '\0';
 
-			length = strlen (varcmdarr->sequence[i].cmd_name);
-			if ( length > MAX_RESOURCE_FIELD_LENGTH )
-				length = MAX_RESOURCE_FIELD_LENGTH;
-			strncpy (cmd_name, varcmdarr->sequence[i].cmd_name,
-			    MAX_RESOURCE_FIELD_LENGTH);
-			cmd_name[(_Int)length] = '\0';
+/*
+ *  Check wether command name was found.
+ *  If the name was not found, get_cmd_string() returns
+ *  DS_WARNING.
+ */
+
+			if ( ret_stat != DS_WARNING )
+			{
+/*
+ * Limit the class_name and the command_name
+ * strings to 19 characters. This is the limit
+ * of the static database name fields.
+ */
+
+				length = strlen (dev_query_out.class_name);
+				if ( length > MAX_RESOURCE_FIELD_LENGTH )
+					length = MAX_RESOURCE_FIELD_LENGTH;
+				strncpy (class_name, dev_query_out.class_name, 
+			    	MAX_RESOURCE_FIELD_LENGTH);
+				class_name[(_Int)length] = '\0';
+
+				length = strlen (varcmdarr->sequence[i].cmd_name);
+				if ( length > MAX_RESOURCE_FIELD_LENGTH )
+					length = MAX_RESOURCE_FIELD_LENGTH;
+				strncpy (cmd_name, varcmdarr->sequence[i].cmd_name,
+			    	MAX_RESOURCE_FIELD_LENGTH);
+				cmd_name[(_Int)length] = '\0';
+			}
 
 /*
  *  setup resource path to read information about
@@ -860,8 +924,8 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
 			if (ds->i_nethost > 0)
 			{
 				sprintf(res_path, "//%s/CLASS/%s/%s",
-				   get_nethost_by_index(ds->i_nethost, error),
-				   class_name, cmd_name);
+		   		get_nethost_by_index(ds->i_nethost, error),
+		   		class_name, cmd_name);
 			}
 /*
  * use default nethost
@@ -869,7 +933,7 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
 			else
 			{
 				sprintf (res_path, "CLASS/%s/%s", 
-				   class_name, cmd_name);
+		   		class_name, cmd_name);
 			}
 
 			/*
@@ -884,6 +948,14 @@ long _DLLFunc dev_cmd_query (devserver ds, DevVarCmdArray *varcmdarr, long *erro
 				return (-1);
 			}
 		}
+/*
+ * no database, set in_name and out_name to NULL
+ */
+		else
+		{
+			varcmdarr->sequence[i].in_name = NULL;
+			varcmdarr->sequence[i].out_name = NULL;
+		}
 	}
 
 	/*
@@ -1416,7 +1488,7 @@ char* _DLLFunc get_nethost_by_index (long i_nethost, long *error)
  Function   :	long extract_device_name()
 
  Description:	Extract the domain/family/member part of name from the 
-		full device name "//nethost/domain/family/member" ,
+		full device name "//nethost/domain/family/member?number" ,
 		return a pointer
 
  Arg(s) In  :	char *full_name - device name
@@ -1429,12 +1501,15 @@ char* _DLLFunc get_nethost_by_index (long i_nethost, long *error)
 	
 char* _DLLFunc extract_device_name (char *full_name, long *error)
 {
-	char *device_name;
+	static char *device_name_alloc=NULL, *device_name;
+	char *prog_url;
 	
 /*
  * assume full_name == device_name to start off with
  */
-	device_name = full_name;
+	device_name_alloc = (char*)realloc(device_name_alloc,strlen(full_name)+1);
+	sprintf(device_name_alloc,"%s",full_name);
+	device_name = device_name_alloc;
 /*
  * if nethost is specified in the device name "remove" it
  */
@@ -1446,6 +1521,11 @@ char* _DLLFunc extract_device_name (char *full_name, long *error)
 		};
 		device_name++;
 	}
+	if (strchr(device_name,'?') != NULL)
+	{
+		prog_url = strchr(device_name, '?');
+		*prog_url = 0;
+	}
 
 	return(device_name);
 }
