@@ -12,12 +12,15 @@
  Original:      July 1993
 
 
- $Revision: 3.67 $
- $Date: 2001/09/13 14:47:49 $
+ $Revision: 3.68 $
+ $Date: 2002/04/03 12:22:10 $
 
- $Author: goetz $
+ $Author: perez $
 
  $Log: BlcDsNumbers.h,v $
+ Revision 3.68  2002/04/03 12:22:10  perez
+ added ISG Serial base
+
  Revision 3.67  2001/09/13 14:47:49  goetz
  added RedLion base number
 
@@ -237,5 +240,7 @@
 #define DevBinemBase   (BlcTeamNumber + DS_LSHIFT(37, DS_IDENT_SHIFT))
 /*-------Redlion device server -------*/
 #define DevRedLionBase   (BlcTeamNumber + DS_LSHIFT(38, DS_IDENT_SHIFT))
+/*-------ISG Serial device server -------*/
+#define DevIsgSerialBase   (BlcTeamNumber + DS_LSHIFT(39, DS_IDENT_SHIFT))
 
 #endif	/* _BlcDsNumbers_h */
