@@ -11,11 +11,14 @@
 
  Original:      Aug 1993
 
- $Revision: 3.39 $
- $Date: 98/10/20 21:12:52 $
+ $Revision: 3.40 $
+ $Date: 2002/04/09 17:31:11 $
 
- $Author: pons $
+ $Author: pepellin $
  $Log:	DasDsNumbers.h,v $
+ * Revision 3.40  2002/04/09  17:31:11  17:31:11  pepellin (G.Pepellin)
+ * Add Barras cmds numbers
+ * 
  * Revision 3.39  98/10/20  21:12:52  21:12:52  pons ()
  * Icv101Base definition deleted and moved to CntrlDsNumbers.h
  * 
@@ -126,5 +129,7 @@
 #define DevV850Base  (DasTeamNumber + DS_LSHIFT(25, DS_IDENT_SHIFT))
 /*** DDA/XDS X-ray Digital Spectroscopy ******/
 #define DevXdsBase  (DasTeamNumber + DS_LSHIFT(26, DS_IDENT_SHIFT))
+/*** Barras Unix device server ***/
+#define DevBarrasBase  (DasTeamNumber + DS_LSHIFT(27, DS_IDENT_SHIFT))
 
 #endif	/* _DasDsNumbers_h */
