@@ -1,6 +1,21 @@
-static char RcsId[] = "@(#)$Header: dc_put.c,v 3.19 99/07/05 14:24:20 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dc_put.c,v 3.24 2002/03/12 11:26:55 goetz Rel $";
 
-/* $Log:	dc_put.c,v $
+/* $Log: dc_put.c,v $
+ * Revision 3.24  2002/03/12 11:26:55  goetz
+ * solaris now uses sigset() and not sigvec anymore
+ *
+ * Revision 3.23  1901/02/20 17:47:17  taurel
+ * Add some test on the ptr retrieved from shared memory for the read server (dc_read.c file)
+ *
+ * Revision 3.22  2001/02/19 12:50:14  goetz
+ * checkin for taurel
+ *
+ * Revision 3.21  2000/12/03 07:19:13  goetz
+ * ported to Linux
+ *
+ * Revision 3.20  2000/03/13 15:28:29  taurel
+ * Adapted to the new release of gettranscient (DSAIPI release 7.8 and above)
+ *
  * Revision 3.19  99/07/05  14:24:20  14:24:20  taurel (E.Taurel)
  * Porte dto new release of gettranscienr_ut. I don't understand how it worked
  * before !!
@@ -143,7 +158,7 @@ dev_datarr *rece;
 /* Call the dev_add_data function for every device */
 
 	for (i = 0;i < dev_number;i++) {
-		if (dev_add_data(rece->dev_datarr_val[i],&err_code)) {
+		if (dev_add_data(&(rece->dev_datarr_val[i]),&err_code)) {
 			ret_err.error_code = err_code;
 			ret_err.dev_error = i + 1;
 			return(&ret_err);
@@ -386,25 +401,45 @@ int *perr;
 			k = 0;
 			tmp_ptr1 = (unsigned char *)tmp_ptr->xsequence.xsequence_val;
 			for (j = 0;j < cmd_info[l].nb_loop;j++) {
+#ifndef linux
 				ptr[i + j] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16) + (tmp_ptr1[k + 2] << 8) + (tmp_ptr1[k + 3]);
+#else
+				ptr[i + j] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8) + (tmp_ptr1[k + 2] << 16) + (tmp_ptr1[k + 3] << 24);
+#endif
 				k = k + 4;
 							}
 			i = i + j;
 			switch(cmd_info[l].extra) {
 				case 0 : 
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16) + (tmp_ptr1[k + 2] << 8) + (tmp_ptr1[k + 3]);
+#else
+				ptr[i] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8) + (tmp_ptr1[k + 2] << 16) + (tmp_ptr1[k + 3] << 24);
+#endif
 				break;
 
 				case 1 :
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16) + (tmp_ptr1[k + 2] << 8);
+#else
+				ptr[i] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8) + (tmp_ptr1[k + 2] << 16);
+#endif
 				break;
 
 				case 2 :
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16);
+#else
+				ptr[i] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8);
+#endif
 				break;
 
 				case 3 :
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24);
+#else
+				ptr[i] = (tmp_ptr1[k]);
+#endif
 				break;
 
 				case 4 :
@@ -460,25 +495,45 @@ int *perr;
 			k = 0;
 			tmp_ptr1 = (unsigned char *)tmp_ptr->xsequence.xsequence_val;
 			for (j = 0;j < cmd_info[l].nb_loop;j++) {
+#ifndef linux
 				ptr[i + j] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16) + (tmp_ptr1[k + 2] << 8) + (tmp_ptr1[k + 3]);
+#else
+				ptr[i + j] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8) + (tmp_ptr1[k + 2] << 16) + (tmp_ptr1[k + 3] << 24);
+#endif
 				k = k + 4;
 							}
 			i = i + j;
 			switch(cmd_info[l].extra) {
 				case 0 : 
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16) + (tmp_ptr1[k + 2] << 8) + (tmp_ptr1[k + 3]);
+#else
+				ptr[i] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8) + (tmp_ptr1[k + 2] << 16) + (tmp_ptr1[k + 3] << 24);
+#endif
 				break;
 
 				case 1 :
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16) + (tmp_ptr1[k + 2] << 8);
+#else
+				ptr[i] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8) + (tmp_ptr1[k + 2] << 16);
+#endif
 				break;
 
 				case 2 :
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24) + (tmp_ptr1[k + 1] << 16);
+#else
+				ptr[i] = (tmp_ptr1[k]) + (tmp_ptr1[k + 1] << 8);
+#endif
 				break;
 
 				case 3 :
+#ifndef linux
 				ptr[i] = (tmp_ptr1[k] << 24);
+#else
+				ptr[i] = (tmp_ptr1[k]);
+#endif
 				break;
 
 				case 4 :
