@@ -1,6 +1,21 @@
-static char RcsId[] = "@(#)$Header: dcwr_svc.c,v 3.19 99/07/05 14:24:27 taurel Rel $";
+static char RcsId[] = "@(#)$Header: /segfs/dserver/system/dc/svc/RCS/dcwr_svc.c,v 3.24 2002/03/12 11:26:55 goetz Rel $";
 
-/* $Log:	dcwr_svc.c,v $
+/* $Log: dcwr_svc.c,v $
+ * Revision 3.24  2002/03/12 11:26:55  goetz
+ * solaris now uses sigset() and not sigvec anymore
+ *
+ * Revision 3.23  1901/02/20 17:47:22  taurel
+ * Add some test on the ptr retrieved from shared memory for the read server (dc_read.c file)
+ *
+ * Revision 3.22  2001/02/19 12:50:14  goetz
+ * checkin for taurel
+ *
+ * Revision 3.21  2000/12/03 07:19:13  goetz
+ * ported to Linux
+ *
+ * Revision 3.20  2000/03/13 15:28:35  taurel
+ * Adapted to the new release of gettranscient (DSAIPI release 7.8 and above)
+ *
  * Revision 3.19  99/07/05  14:24:27  14:24:27  taurel (E.Taurel)
  * Porte dto new release of gettranscienr_ut. I don't understand how it worked
  * before !!
@@ -201,10 +216,13 @@ char *argv[];
 	struct sockaddr_in so;
 	char hostna[32];
 	char full_name[80];
-#ifdef sun
+#ifdef OBSOLETE_SUN
 	int sig_mask;
 	struct sigvec sighand;
 #endif
+#ifdef linux
+	struct sigaction sigact;
+#endif /* linux */
 
 /* Added variables to manage transient program number */
 
@@ -228,7 +246,7 @@ char *argv[];
 
 /* Install signal handlers */
 
-#ifdef sun
+#ifdef OBSOLETE_SUN
 	sig_mask = sigmask(SIGHUP);
 	sigsetmask(sig_mask);
 
@@ -255,6 +273,7 @@ char *argv[];
 	sigvec(SIGXCPU,&sighand,NULL);
 	sigvec(SIGXFSZ,&sighand,NULL);
 #else
+#ifndef linux
 	(void) sigignore(SIGHUP);
 	(void) sigset(SIGINT, un_register_prog);
 	(void) sigset(SIGQUIT, un_register_prog);
@@ -265,7 +284,31 @@ char *argv[];
 	(void) sigset(SIGUSR2, default_sig);
 	(void) sigset(SIGVTALRM, default_sig);
 	(void) sigset(SIGPROF, default_sig);
+#ifndef _solaris
 	(void) sigset(SIGLOST, default_sig);
+#endif /* _solaris */
+#else
+        sigact.sa_handler = SIG_IGN;
+        sigaction(SIGHUP, &sigact, NULL);
+        sigact.sa_handler = un_register_prog;
+        sigaction(SIGINT, &sigact, NULL);
+        sigact.sa_handler = un_register_prog;
+        sigaction(SIGQUIT, &sigact, NULL);
+        sigact.sa_handler = un_register_prog;
+        sigaction(SIGTERM, &sigact, NULL);
+        sigact.sa_handler = time_out_prog;
+        sigaction(SIGALRM, &sigact, NULL);
+        sigact.sa_handler = default_sig;
+        sigaction(SIGPIPE, &sigact, NULL);
+        sigact.sa_handler = default_sig;
+        sigaction(SIGUSR1, &sigact, NULL);
+        sigact.sa_handler = default_sig;
+        sigaction(SIGUSR2, &sigact, NULL);
+        sigact.sa_handler = default_sig;
+        sigaction(SIGVTALRM, &sigact, NULL);
+        sigact.sa_handler = default_sig;
+        sigaction(SIGPROF, &sigact, NULL);
+#endif /* !linux */                                                             
 #endif
 
 /* Change max number of open files */
@@ -291,7 +334,7 @@ char *argv[];
 	strcat(full_name,"/");
 	strcat(full_name,argv[1]);
 	
-	pgnum = gettransient_ut(full_name,&sock_udp,&sock_tcp);
+	pgnum = gettransient(full_name);
 
 	if (pgnum == 0)
 	{
@@ -304,11 +347,6 @@ char *argv[];
 	printf("Program number : %x in hexa or %d in decimal\n",pgnum,pgnum);
 #endif /* DEBUG */
 
-#ifdef _solaris
-	close(sock_tcp);
-	sock_tcp = RPC_ANYSOCK;
-	pmap_unset (pgnum,DC_VERS);
-#endif /* _solaris */
 
 	transp_tcp = svctcp_create(sock_tcp,0,0);
 
@@ -328,11 +366,6 @@ char *argv[];
 
 /* Register the server with the UDP protocol */
 
-#ifdef _solaris
-	close(sock_udp);
-	sock_udp = RPC_ANYSOCK;
-#endif /* _solaris */
-
 	transp_udp = svcudp_create(sock_udp);
 	if (transp_udp == NULL)
 	{
@@ -470,7 +503,7 @@ dc_prog_1(rqstp, transp)
 	switch (rqstp->rq_proc)
 	{
 	case NULLPROC:
-		svc_sendreply(transp, xdr_void, NULL);
+		svc_sendreply(transp, (const xdrproc_t)xdr_void, (caddr_t)NULL);
 		return;
 
 	case DC_OPEN:
@@ -511,11 +544,11 @@ dc_prog_1(rqstp, transp)
 
 	case RPC_CHECK:
 		tmp_ch = ds_name;
-		svc_sendreply(transp,xdr_wrapstring,(caddr_t)&tmp_ch);
+		svc_sendreply(transp,(const xdrproc_t)xdr_wrapstring,(caddr_t)&tmp_ch);
 		return;
 
 	case RPC_QUIT_SERVER:
-		svc_sendreply(transp,xdr_void,NULL);
+		svc_sendreply(transp,(const xdrproc_t)xdr_void,(caddr_t)NULL);
 		pid = getpid();
 		kill(pid,SIGQUIT);
 		return;
@@ -527,17 +560,17 @@ dc_prog_1(rqstp, transp)
 
 	memset(&argument, 0, sizeof(argument));
 
-	if (!svc_getargs(transp, xdr_argument, (caddr_t)&argument))
+	if (!svc_getargs(transp, (const xdrproc_t)xdr_argument, (caddr_t)&argument))
 	{
 		svcerr_decode(transp);
 		return;
 	}
 	result = (*local)(&argument, rqstp);
-	if (result != NULL && !svc_sendreply(transp, xdr_result, result))
+	if (result != NULL && !svc_sendreply(transp, (const xdrproc_t)xdr_result, (caddr_t)result))
 	{
 		svcerr_systemerr(transp);
 	}
-	if (!svc_freeargs(transp, xdr_argument, (caddr_t)&argument))
+	if (!svc_freeargs(transp, (const xdrproc_t)xdr_argument, (caddr_t)&argument))
 	{
 		fprintf(stderr, "unable to free arguments\n");
 		exit(1);
